summaryrefslogtreecommitdiff
path: root/slang.h
diff options
context:
space:
mode:
Diffstat (limited to 'slang.h')
-rw-r--r--slang.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/slang.h b/slang.h
index 0d9c0b44a..14e9a30e2 100644
--- a/slang.h
+++ b/slang.h
@@ -1100,7 +1100,7 @@ extern "C"
typedef void(*SlangFuncPtr)(void);
/**
- (DEPRECIATED) ISlangSharedLibrary
+ (DEPRECATED) ISlangSharedLibrary
*/
struct ISlangSharedLibrary_Dep1: public ISlangUnknown
{
@@ -3365,7 +3365,7 @@ namespace slang
SlangPassThrough passThrough,
char const* path) = 0;
/** DEPRECIATED: Use setLanguagePrelude
Set the 'prelude' for generated code for a 'downstream compiler'.
@param passThrough The downstream compiler for generated code that will have the prelude applied to it.
@@ -3377,7 +3377,7 @@ namespace slang
SlangPassThrough passThrough,
const char* preludeText) = 0;
/** DEPRECIATED: Use getLanguagePrelude
Get the 'prelude' for generated code for a 'downstream compiler'.
@param passThrough The downstream compiler for generated code that will have the prelude applied to it.
@@ -3365,7 +3365,7 @@ namespace slang
SlangPassThrough passThrough,
char const* path) = 0;
- /** DEPRECIATED: Use setLanguagePrelude
+ /** DEPRECATED: Use setLanguagePrelude
Set the 'prelude' for generated code for a 'downstream compiler'.
@@ -3377,7 +3377,7 @@ namespace slang
SlangPassThrough passThrough,
const char* preludeText) = 0;
- /** DEPRECIATED: Use getLanguagePrelude
+ /** DEPRECATED: Use getLanguagePrelude
Get the 'prelude' for generated code for a 'downstream compiler'.